@@ -8,7 +8,6 @@ from django.utils.translation import ugettext as _
 
 from cmsutils.utils import QuerySetWrapper
 
-
 IN_LOOKUP = '__in'
 PAGE_VAR = 'p'
 
@@ -95,7 +94,9 @@ class QueryStringManager(object):
             else:
                 raw_filters[key] = l
 
-        for key, l in raw_filters.items():
+        good_filters = self.sanitize_filters(raw_filters)
+
+        for key, l in good_filters.items():
             try:
                 key = str(key)
             except UnicodeEncodeError:
@@ -108,6 +109,9 @@ class QueryStringManager(object):
             else:
                 self._set_into_dict(self.filters, key, l)
 
+    def sanitize_filters(self, filters):  # hook to searchform
+        return filters
+
     def _get_from_dict(self, multidict, key):
         if key.endswith(IN_LOOKUP):
             return multidict.getlist(str(key))
@@ -172,14 +176,14 @@ class QueryStringManager(object):
         filters = {}
         for key in self.filters.keys():
             filters[key] = self._get_from_dict(self.filters, key)
-        return filters
+        return self.sanitize_filters(filters)
 
     def get_excluders(self):
         excluders = {}
         for key in self.excluders.keys():
             filter_key = key.replace('not_', '')
             excluders[filter_key] = self._get_from_dict(self.excluders, key)
-        return excluders
+        return self.sanitize_filters(excluders)
 
     def get_filters_items(self):
         return self._get_multidict_items(self.filters)
